@@ -77,8 +77,8 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     valBW = "L"
     wMaximized = True
     lockUpdating = False
-    curImageLoc ="ui/resources/landscapeRepo.jpg"
-    plotIm = Image.open(os.getcwd()+"/ui/resources/graph.png") 
+    curImageLoc ="/opt/anselA/ui/resources/landscapeRepo.jpg"
+    plotIm = Image.open("/opt/anselA/ui/resources/graph.png") 
     curIm =""
     curThumb = ""
     valCurTab=0
